<?php

namespace Drupal\commerce_stripe_payment_request_button\Event;

use Drupal\commerce\EventBase;
use Drupal\commerce_order\Entity\OrderInterface;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Defines the order event.
 *
 * @see \Drupal\commerce_order\Event\OrderEvents
 */
class OrderEvent extends EventBase {

    /**
     * The order.
     *
     * @var \Drupal\commerce_order\Entity\OrderInterface
     */
    protected $order;

    /**
     * The StripePaymentRequestButton configuration.
     *
     * @var \Drupal\Core\Config\ImmutableConfig
     */
    protected $config;

    /**
     * Constructs a new OrderEvent.
     *
     * @param \Drupal\commerce_order\Entity\OrderInterface $order
     *   The order.
     *
     * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
     *   The configuration factory.
     */
    public function __construct(OrderInterface $order, ConfigFactoryInterface $config) {
        $this->order = $order;
        $this->config = $config;
    }

    /**
     * Gets the order.
     *
     * @return \Drupal\commerce_order\Entity\OrderInterface
     *   Gets the order.
     */
    public function getOrder() {
        return $this->order;
    }

    /**
     * Gets the order.
     *
     * @return \Drupal\commerce_order\Entity\OrderInterface
     *   Gets the order.
     */
    public function getConfiguration() {
        return $this->config;
    }
}
